package cz.zweistein.gw.predictor;

import java.util.Collections;
import java.util.List;

import org.apache.log4j.Logger;

import cz.zweistein.gw.predictor.comparators.PredicableByLadder;
import cz.zweistein.gw.predictor.comparators.PredicableByPredicted;
import cz.zweistein.gw.predictor.comparators.PredicableByQP;
import cz.zweistein.gw.predictor.comparators.PredicateByRatios;
import cz.zweistein.gw.predictor.controller.XTHRemote;

public class Guilds {
	
	private static Logger logger = Logger.getLogger(Guilds.class);
	
	private List<Guild> guilds;
	
	public Guilds(XTHRemote xthRemote) {
		this.guilds = xthRemote.getQualifiedGuilds();
	}

	public List<Guild> getGuilds() {
		return this.guilds;
	}

	public List<Guild> prepareVotes(Ratios ratios) {
		
		Collections.sort(this.guilds, new PredicableByLadder());
		for (int i = 0; i < this.guilds.size(); i++) {
			this.guilds.get(i).setLadderRatingOrder(i);
		}
		
		Collections.sort(this.guilds, new PredicableByQP());
		for (int i = 0; i < this.guilds.size(); i++) {
			this.guilds.get(i).setQualifierPointsOrder(i);
		}
		
		Collections.sort(this.guilds, new PredicableByPredicted());
		for (int i = 0; i < this.guilds.size(); i++) {
			this.guilds.get(i).setPredictionOrder(i);
		}
		
		//we have now normalized prediction for all four types.
		
		Collections.sort(this.guilds, new PredicateByRatios(ratios));
		
		return this.guilds.subList(0, 8);
		
	}

	public Guild getGuildForName(String guildName) {
		
		for (Guild guild : this.guilds) {
			if (guild.getName().equalsIgnoreCase(guildName.trim())) {
				return guild;
			}
		}
		
		logger.info("Guild " + guildName + " not found - either invalid or unqualified");
		return null;
	}
	
}
