package cz.zweistein.gw.predictor;

import java.util.LinkedList;

import org.apache.log4j.Logger;

public class Predicable {
	private static Logger logger = Logger.getLogger(Predicable.class);
	
	private String name;
	private String id;

	protected LinkedList<Integer> pastOrders;
	
	private float prediction = 16;
	private int qualifierPoints;
	private int ladderRating;
	
	private int predictionOrder;
	private int qualifierPointsOrder;
	private int ladderRatingOrder;
	
	public String getId() {
		return this.id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public void addOrder(int order) {
		this.pastOrders.addLast(order);
	}
	
	public String getName() {
		return this.name;
	}
	
	public void setName(String name) {
		this.name = name;
	}
	
	private float getFloatingAverageOrder() {
		if (this.pastOrders.size() == 0){
			// logger.info(this.getId() + " " + this.getName() + " does not have any past results.");
			// we do not have any past results, lets assume they are bad at GW 
			this.prediction = 16;
			return this.prediction;
		} 
		
		float predictedOrder = this.pastOrders.getFirst();
		
		for (Integer order : this.pastOrders) {
			if (order != null) {
				// skip month without ratings.
				predictedOrder = (predictedOrder + order)/2;
			}
		}
		
		this.prediction = predictedOrder;
		return this.prediction;
	}
	
	public float getPredictedOrder() {
		return this.getFloatingAverageOrder();
	}

	public int getQualifierPoints() {
		return this.qualifierPoints;
	}

	public void setQualifierPoints(int qualifierPoints) {
		this.qualifierPoints = qualifierPoints;
	}

	public int getLadderRating() {
		return this.ladderRating;
	}

	public void setLadderRating(int ladderRating) {
		this.ladderRating = ladderRating;
	}

	public int getPredictionOrder() {
		return this.predictionOrder;
	}

	public void setPredictionOrder(int predictionOrder) {
		this.predictionOrder = predictionOrder;
	}

	public int getQualifierPointsOrder() {
		return this.qualifierPointsOrder;
	}

	public void setQualifierPointsOrder(int qualifierPointsOrder) {
		this.qualifierPointsOrder = qualifierPointsOrder;
	}

	public int getLadderRatingOrder() {
		return this.ladderRatingOrder;
	}

	public void setLadderRatingOrder(int ladderRatingOrder) {
		this.ladderRatingOrder = ladderRatingOrder;
	}

	public float getAgregateOrder(Ratios ratios) {
		
		 float agregateOrder = ((this.getPredictionOrder() * ratios.getPredictionOrder()) +
		 	(this.getLadderRatingOrder() * ratios.getLadderRatingOrder()) +
		 	(this.getQualifierPointsOrder() * ratios.getQualifierPointsOrder())) /
		 	
		 	(ratios.getPredictionOrder() + ratios.getLadderRatingOrder() + ratios.getQualifierPointsOrder());
		 	
		
		return agregateOrder;
	}
}
