package cz.zweistein.gw.predictor;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

import org.apache.log4j.Logger;

import cz.zweistein.gw.predictor.comparators.PredicableByPredicted;
import cz.zweistein.gw.predictor.controller.ConfigurationLoader;
import cz.zweistein.gw.predictor.controller.ConfigurationLoaderImpl;
import cz.zweistein.gw.predictor.controller.XTHRemote;
import cz.zweistein.gw.predictor.model.Configuration;
import cz.zweistein.gw.predictor.model.User;

public class Predictor {
	private static Logger logger = Logger.getLogger(Predictor.class);

	public static void main(String[] args) throws Exception {
		
		logger.info("Xunlai tournament Vote v0.3");
		logger.info("[z] Zweistein 2009");
		
		ConfigurationLoader configurationLoader = new ConfigurationLoaderImpl();
		Configuration config = configurationLoader.loadConfiguration();
		XTHRemote xth = new XTHRemote();
		
		if (config.getVotedGuild().size()==0) {
			logger.info("Incomplete votes for GvG presented, attempting to predict automatically.");
			// no guild predictions, we are going to predict them old-style
			List<Guild> qualifiedGuilds = xth.getQualifiedGuilds();
			if (qualifiedGuilds.size() >= 8 ) {
				xth.fillInGuildTournamentHistory(qualifiedGuilds);
				Collections.sort(qualifiedGuilds, new PredicableByPredicted());
				for (int i=0; i < 8 ; i++) {
					config.getVotedGuild().add(qualifiedGuilds.get(i).getName());
				}
				logger.info("Chosen " + config.getVotedGuild());
			} else {
				logger.error("Not enough guilds qualified to make pick.");
			}
		}
		
		if (config.getVotedPlayer().size()==0) {
			logger.info("Incomplete votes for 1v1 presented, attempting to predict automatically.");
			// no guild predictions, we are going to predict them old-style
			List<Player> qualifiedPlayers = xth.getQualifiedPlayers();
			if (qualifiedPlayers.size() >= 8 ) {
				xth.fillInPlayerTournamentHistory(qualifiedPlayers);
				Collections.sort(qualifiedPlayers, new PredicableByPredicted());
				for (int i=0; i < 8 ; i++) {
					config.getVotedPlayer().add(qualifiedPlayers.get(i).getName());
				}
				logger.info("Chosen " + config.getVotedPlayer());
			} else {
				logger.error("Not enough players qualified to make pick.");
			}
		}
		
		for (User user : config.getUsers()) {
			xth.logIn(user);
			
			if (xth.isLoggedIn()) {
				
				logger.info("Voting for:" + user.getEmail());
				
				Guilds qualifiedGuilds = new Guilds(xth);
				List<Guild> preparedGuildVotes = new LinkedList<Guild>();
				for (String guildName : config.getVotedGuild()) {
					Guild guild = qualifiedGuilds.getGuildForName(guildName);
					preparedGuildVotes.add(guild);
				}
				xth.voteForGvG(preparedGuildVotes);
				
				Players qualifiedPlayers = new Players(xth);
				List<Player> preparedPlayerVotes = new LinkedList<Player>();
				for (String playerName : config.getVotedPlayer()) {
					Player player = qualifiedPlayers.gePlayerForName(playerName);
					preparedPlayerVotes.add(player);
				}
				xth.voteFor1v1(preparedPlayerVotes);
				
				logger.info("Done for " + user.getEmail());
			}
		}
		
	}

}
